
.. _contents:

Welcome to RKI COVID-19 API Python Client's documentation!
==========================================================

A Thin Python Wrapper for the `COVID-19 API`_ of the Robert Koch Institute, Germany.

.. _COVID-19 API: https://api.corona-zahlen.org/docs/

Documentation
-------------

.. only:: html

    :Release: |version|
    :Date: |today|

.. toctree::
   :maxdepth: 1

   install
   tutorial
   data
